EnvironmentAnalysisMode

Enum EnvironmentAnalysisMode 

pub enum EnvironmentAnalysisMode {
    AlwaysAvailable,
    Bounded {
        max_tokens: usize,
    },
    Ignore,
}
How environment places should be treated during verification. Controls how environment places (external event sources) are treated during formal analysis.

Variants



AlwaysAvailable

Environment places are always considered to have tokens available. Transitions reading from environment places are always enabled.



Bounded

Environment places are treated as having at most max_tokens tokens. Explores states where 0..=max_tokens tokens are injected.

Fields

max_tokens: usize


Ignore

Environment places are treated as regular places (no special handling).